@import url(https://fonts.googleapis.com/css2?family=Ubuntu:wght@700&display=swap);body{margin:0;font-family:-apple-system,BlinkMacSystemFont,"Segoe UI","Roboto","Oxygen","Ubuntu","Cantarell","Fira Sans","Droid Sans","Helvetica Neue",sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}code{font-family:source-code-pro,Menlo,Monaco,Consolas,"Courier New",monospace}.App{text-align:center;font-family:"Ubuntu",sans-serif}
/*# sourceMappingURL=main.e59da69f.chunk.css.map */