self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "f56593ea3a791f73dbdcba3c2b7cc3f5",
    "url": "/index.html"
  },
  {
    "revision": "3d80b2057de268768394",
    "url": "/static/css/main.e59da69f.chunk.css"
  },
  {
    "revision": "ac0edde365ae85218b39",
    "url": "/static/js/2.3a10aaba.chunk.js"
  },
  {
    "revision": "64bea2e190f27355a76963b8cb94bb7b",
    "url": "/static/js/2.3a10aaba.chunk.js.LICENSE.txt"
  },
  {
    "revision": "3d80b2057de268768394",
    "url": "/static/js/main.842bbfb2.chunk.js"
  },
  {
    "revision": "2b41416c862a3df9f773",
    "url": "/static/js/runtime-main.2fa1d660.js"
  },
  {
    "revision": "3c82aef93b11bef40af4bb1a90ee36af",
    "url": "/static/media/menu_logo.3c82aef9.png"
  }
]);